- ${XML(item.blurb(html=1))}

${XML(member.blurb(html=1))}

#### ${member_sigil(member.type_name)} `${member.name}`

    ${pp.pformat(member.obj)}

#### ${member_sigil(member.type_name)} `${member.name}${member.formatargs()}` ...

${member_doc(member)}

#### ${member_sigil(member.type_name)} `${member.name}${member.formatargs()}` ...

${member_doc(member)}

This class contains ${member_count} member${member_count > 1 and 's' or ''}.

##

`${myname}`
  ${XML(module.blurb(html=1))}

${sigil_for_type(type)}